#include "entity.h"
#include "debuggers.h"

namespace pabloader {
Entity::Entity(Debuggers* game, olc::Sprite* s): sprite(s), w(s->width / 4), h(s->height / 4)
{
    Entity::game = game;
}

void Entity::Update(float dt)
{
    y += yv * dt;
    yv += game->gravity * dt;

    rotation += rotationSpeed * dt;

    transform.Reset();
    transform.Rotate(rotation);
    transform.Translate(x, y);
}

bool Entity::Collides(Entity* entity)
{
    bool collidesX = (x - w / 2 < entity->x + entity->w / 2) && (entity->x - entity->w / 2 < x + w / 2);
    bool collidesY = (y - h / 2 < entity->y + entity->h / 2) && (entity->y - entity->h / 2 < y + h / 2);
    return collidesX && collidesY;
}

void Entity::Draw()
{
#ifdef _DEBUG
    game->DrawRect(x - w / 2, y - h / 2, w, h, DEBUG_COLOR);
#endif
    olc::GFX2D::DrawPartialSprite(sprite, tileX * w, tileY * h, w, h, transform, true);
}

bool Entity::IsActive()
{
    return y - h / 2 < game->GameScreenHeight();
}

void Entity::ResetPosition()
{
    y = game->GetRandom(-20, -game->ScreenHeight());
    x = game->GetRandom(w, game->ScreenWidth() - w);
    yv = 0;
    tileX = game->GetRandom<int>(0, tileCols);
    tileY = game->GetRandom<int>(0, tileRows);
    rotationSpeed = game->GetRandom(-3.14f, 3.14f);
}

void Entity::Kill()
{
    y = game->ScreenHeight() + 100;
}
}